@@ -15,15 +15,15 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 15
+#define ARROW_VERSION_MAJOR 16
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 2
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "15.0.2"
+#define ARROW_VERSION_STRING "16.0.0"
 
-#define ARROW_SO_VERSION "1500"
-#define ARROW_FULL_SO_VERSION "1500.2.0"
+#define ARROW_SO_VERSION "1600"
+#define ARROW_FULL_SO_VERSION "1600.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "17.0.6"
@@ -47,15 +47,27 @@
 #define ARROW_JEMALLOC
 #define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
+/* #undef ARROW_MIMALLOC */
 #define ARROW_ORC
 #define ARROW_PARQUET
 #define ARROW_SUBSTRAIT
 
+/* #undef ARROW_AZURE */
 #define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
+#define ARROW_HDFS
 /* #undef ARROW_S3 */
+#define ARROW_USE_GLOG
 /* #undef ARROW_USE_NATIVE_INT128 */
+#define ARROW_WITH_BROTLI
+#define ARROW_WITH_BZ2
+#define ARROW_WITH_LZ4
 /* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
+#define ARROW_WITH_RE2
+#define ARROW_WITH_SNAPPY
 /* #undef ARROW_WITH_UCX */
+#define ARROW_WITH_UTF8PROC
+#define ARROW_WITH_ZLIB
+#define ARROW_WITH_ZSTD
 #define PARQUET_REQUIRE_ENCRYPTION
